.. HookMan documentation master file, created by
   sphinx-quickstart on Fri Aug 17 14:18:45 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: ../../README.rst

What's next?
============

To get quick and running with ``HookMan`` you can read the :ref:`quick-start-section` section.

.. toctree::
    :maxdepth: 2
    :glob:

    quick_start

After reading the quick start section, check out these additional resources to help better understand the project flow:

.. toctree::
    :maxdepth: 2
    :glob:

    concepts/creating_hook_specs
    concepts/creating_plugins

In order to integrate the ``HookMan`` project in your application, by listing available plugins and checking conflicts read the section:

.. toctree::
    :maxdepth: 2
    :glob:

    concepts/application_usage


Dig deeper into specific topics:

.. toctree::
    :maxdepth: 2
    :glob:

    concepts/creating_an_sdk
    api/*
